@@ -1,12 +1,12 @@
-import { $, $$, browser, ExpectedConditions as until } from 'protractor';
+import { $, $$, browser, ExpectedConditions as until, by, element } from 'protractor';
 
 const BROWSER_TIMEOUT = 15000;
 
 const inputs = $$('.form-control');
 export const rowsKey = $('[placeholder="name"]');
 export const rowsValue = $('[placeholder="value"]');
-export const deleteBtn = $('.pairs-list__delete-icon');
-export const saveBtn = $$('.btn-primary').filter(link => link.getText().then(text => text.startsWith('Save'))).first();
+export const deleteBtn = $$('.pairs-list__delete-icon').first();
+export const saveBtn = element(by.cssContainingText('.btn.btn-primary', 'Save'));
 
 export const isLoaded = () => browser.wait(until.presenceOf(inputs.first()), BROWSER_TIMEOUT);
 
